@@ -9,9 +9,9 @@ from _utils import get_ip
 class Client(Node):
 	def __init__(self, ip = None, port = None):
 		self._is_Node_init = False
-		if ip == None:
+		if ip is None:
 			ip = get_ip()
-		if port == None:
+		if port is None:
 			port = 0
 
 		self._ip = ip
@@ -19,20 +19,28 @@ class Client(Node):
 
 		self._connection = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 		self._connection.bind((ip, port))
-		self._address = self._connection.getsockname()
+		Node.__init__(self, self._connection)
+
+	def connect(self, ip, port=None):
+		if port is None:
+			port = ip[1]
+			ip = ip[0]
+
+		server_address = self.server_address
+		try:
+			if server_address[0] == ip and server_address[1] == port and not self.is_closed:
+				return
+		except:
+			pass
 
-	def connect(self, ip, port = None):
 		if self._is_Node_init and not self.is_closed:
 			self.close()
 
-		server_address = ip
-		if port != None:
-			server_address = (ip, port)
-
-		if self._connection == None:
+		if self._connection is None:
 			self._connection = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 			self._connection.bind((self._ip, self._port))
-			self._address = self._connection.getsockname()
 
-		self._connection.connect(server_address)
-		Node.__init__(self, self._connection)
\ No newline at end of file
+		self._connection.connect((ip, port))
+		Node.__init__(self, self._connection)
+		self._start()
+		
\ No newline at end of file
