@@ -1,6 +1,5 @@
 import threading
 import dill
-import multiprocessing
 import sys
 import os
 import traceback
@@ -8,6 +7,8 @@ import uuid
 from concurrent.futures import ThreadPoolExecutor
 
 sys.path.append(os.path.dirname(os.path.realpath(__file__)))
+from _CloseableQueue import CloseableQueue
+from _CloseablePipe import CloseablePipe
 import _NodeInternalClasses
 
 complex_request = ["get_file", "put_file",
@@ -17,46 +18,50 @@ complex_request = ["get_file", "put_file",
 	               "execfile", "exec_remote_file"]
 
 def __init__(self, connection, server = None):
-	# session id:
-	# request a new session id use -1
-	# close, write_to_file, close_file, put back session id use -2
-
 	self._is_Node_init = True
 	self._connection = connection
-
-	self._server = server
-
+	self._parent = server
 	self._pipes = _NodeInternalClasses.Pipes(self)
 	self._queues = _NodeInternalClasses.Queues(self)
 	self._result_queues_for_future = _NodeInternalClasses.Queues(self, private=True)
-	self._recved_binary_queue = _NodeInternalClasses.CloseableQueue()
+	self._recved_binary_queue = CloseableQueue()
 
-	if self._server == None:
+	if self._parent is None:
 		self._local_vars = {}
-		self._pipe = multiprocessing.Pipe()
-		self._queue = _NodeInternalClasses.CloseableQueue()
-		self._actual_pipes = {}
-		self._actual_queues = {}
-		self._actual_result_queues_for_future = {}
-		self._address = self._connection.getsockname()
-		self._server_address = self._connection.getpeername()
+		self._pipe = CloseablePipe()
+		self._queue = CloseableQueue()
+		self._actual_pipes = _NodeInternalClasses.PipeDict()
+		self._actual_queues = _NodeInternalClasses.QueueDict()
+		self._actual_result_queues_for_future = _NodeInternalClasses.QueueDict()
+		self._server_peer = _NodeInternalClasses.ServerPeer(self)
 	else:
-		self._address = self._connection.getpeername()
-		self._server_address = server.address
+		self._server_peer = self._parent
 		
-	self._globals = _NodeInternalClasses.Globals(self)
 	self._recving_thread = None
 	self._decoding_thread = None
 
 	self._recved_responses = _NodeInternalClasses.QueueDict()
 	self._recved_signals = _NodeInternalClasses.QueueDict()
-	
-	self._simple_threads_pool = None
-	self._complex_threads_pool = None
 
 	self._out_file = None
 
-	self._start()
+	self._simple_threads_pool = None
+	self._complex_threads_pool = None
+	
+def _start(self):
+	if self._simple_threads_pool is None:
+		self._simple_threads_pool = ThreadPoolExecutor(max_workers=5)
+
+	if self._complex_threads_pool is None:
+		self._complex_threads_pool = ThreadPoolExecutor(max_workers=1)
+
+	if self._recving_thread is None or not self._recving_thread.is_alive():
+		self._recving_thread = threading.Thread(target=self._recving_loop, daemon=True)
+		self._recving_thread.start()
+
+	if self._decoding_thread is None or not self._decoding_thread.is_alive():
+		self._decoding_thread = threading.Thread(target=self._decoding_loop, daemon=True)
+		self._decoding_thread.start()
 
 def __del__(self):
 	try:
@@ -68,7 +73,7 @@ def hold_on(self):
 	threading.Event().wait()
 
 def close(self):
-	if self._server == None:
+	if self._parent is None:
 		try:
 			self._request(session_id=-2)
 		except:
@@ -80,8 +85,6 @@ def close(self):
 			pass
 
 		self._connection = None
-		self._address = None
-		self._server_address = None
 
 		try:
 			self._queue.close()
@@ -103,31 +106,20 @@ def close(self):
 		except:
 			pass
 
-		for key in self._actual_queues:
-			try:
-				self._actual_queues[key].close()
-			except:
-				pass
-		self._actual_queues.clear()
+		try:
+			self._actual_queues.clear()
+		except:
+			pass
 
-		for key in self._actual_pipes:
-			try:
-				self._actual_pipes[key][0].close()
-			except:
-				pass
+		try:
+			self._actual_result_queues_for_future.clear()
+		except:
+			pass
 
-			try:
-				self._actual_pipes[key][1].close()
-			except:
-				pass
-		self._actual_pipes.clear()
-
-		for key in self._actual_result_queues_for_future:
-			try:
-				self._actual_result_queues_for_future[key].close()
-			except:
-				pass
-		self._actual_result_queues_for_future.clear()
+		try:
+			self._actual_pipes.clear()
+		except:
+			pass
 
 	else:
 		try:
@@ -138,26 +130,24 @@ def close(self):
 		self._connection = None
 		
 		try:
-			if self.address != None:
-				self._server.disconnect_result[self.address] = self._server._callback_threads_pool.submit(self._server._onDisconnect, self.address)
+			if self.address is not None:
+				self._parent.disconnect_result[self.address] = self._parent._callback_threads_pool.submit(self._parent._on_disconnected, self.address)
 		except:
 			pass
 
 		try:
-			self._server._connected_nodes.pop(self.address)
+			self._parent._connected_nodes.pop(self.address)
 		except:
 			pass
 
-		self._address = None
-
-	if self._simple_threads_pool != None:
+	if self._simple_threads_pool is not None:
 		try:
 			self._simple_threads_pool.shutdown()
 		except:
 			pass
 		self._simple_threads_pool = None
 
-	if self._complex_threads_pool != None:
+	if self._complex_threads_pool is not None:
 		try:
 			self._complex_threads_pool.shutdown()
 		except:
@@ -174,18 +164,6 @@ def close(self):
 	except:
 		pass
 
-def _start(self):
-	self._simple_threads_pool = ThreadPoolExecutor(max_workers=5)
-	self._complex_threads_pool = ThreadPoolExecutor(max_workers=1)
-
-	if self._recving_thread == None or not self._recving_thread.is_alive():
-		self._recving_thread = threading.Thread(target=self._recving_loop, daemon=True)
-		self._recving_thread.start()
-
-	if self._decoding_thread == None or not self._decoding_thread.is_alive():
-		self._decoding_thread = threading.Thread(target=self._decoding_loop, daemon=True)
-		self._decoding_thread.start()
-
 def _get_session_id(self):
 	return str(uuid.uuid1())
 
@@ -196,10 +174,8 @@ def _close_session(self, sid):
 	if sid in self._recved_responses:
 		del self._recved_responses[sid]
 
-	if self._server == None:
-		if sid in self._actual_result_queues_for_future:
-			self._actual_result_queues_for_future[sid].close()
-			del self._actual_result_queues_for_future[sid]
+	if self._parent is None:
+		del self._actual_result_queues_for_future[sid]
 
 def _traceback(self, remote=True):
 	exception_list = traceback.format_stack()
@@ -209,7 +185,7 @@ def _traceback(self, remote=True):
 
 	exception_str = "Traceback (most recent call last):\n"
 	if remote:
-		exception_str = "Remote"+str(self._server_address) + " " + exception_str
+		exception_str = "Remote" + str(self.server_address) + " " + exception_str
 
 	exception_str += "".join(exception_list)
 
